@@ -64,6 +64,7 @@
 #include <view/view_controls.h>
 #include <wx/log.h>
 
+#include "symb_transforms_utils.h"
 
 SELECTION_CONDITION EE_CONDITIONS::SingleSymbol = []( const SELECTION& aSel )
 {
@@ -148,6 +149,12 @@ SELECTION_CONDITION EE_CONDITIONS::AllPins = []( const SELECTION& aSel )
 };
 
 
+SELECTION_CONDITION EE_CONDITIONS::AllPinsOrSheetPins = []( const SELECTION& aSel )
+{
+    return aSel.GetSize() >= 1 && aSel.OnlyContains( { SCH_PIN_T, SCH_SHEET_PIN_T } );
+};
+
+
 #define HITTEST_THRESHOLD_PIXELS 5
 
 
@@ -364,6 +371,42 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
     KIID lastRolloverItem = niluuid;
     EE_GRID_HELPER grid( m_toolMgr );
 
+    auto pinOrientation =
+        []( EDA_ITEM* aItem )
+        {
+            SCH_PIN* pin = dynamic_cast<SCH_PIN*>( aItem );
+
+            if( pin )
+            {
+                const SCH_SYMBOL* parent = dynamic_cast<const SCH_SYMBOL*>( pin->GetParentSymbol() );
+
+                if( !parent )
+                    return pin->GetOrientation();
+                else
+                {
+                    LIB_PIN dummy( *pin->GetLibPin() );
+                    RotateAndMirrorPin( dummy, parent->GetOrientation() );
+                    return dummy.GetOrientation();
+                }
+            }
+
+            SCH_SHEET_PIN* sheetPin = dynamic_cast<SCH_SHEET_PIN*>( aItem );
+
+            if( sheetPin )
+            {
+                switch( sheetPin->GetSide() )
+                {
+                default:
+                case SHEET_SIDE::LEFT:   return PIN_ORIENTATION::PIN_RIGHT;
+                case SHEET_SIDE::RIGHT:  return PIN_ORIENTATION::PIN_LEFT;
+                case SHEET_SIDE::TOP:    return PIN_ORIENTATION::PIN_DOWN;
+                case SHEET_SIDE::BOTTOM: return PIN_ORIENTATION::PIN_UP;
+                }
+            }
+
+            return PIN_ORIENTATION::PIN_LEFT;
+        };
+
     // Main loop: keep receiving events
     while( TOOL_EVENT* evt = Wait() )
     {
@@ -621,8 +664,11 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
             else if( *evt->GetCommandId() >= ID_POPUP_SCH_PIN_TRICKS_START
                      && *evt->GetCommandId() <= ID_POPUP_SCH_PIN_TRICKS_END )
             {
-                if( !m_selection.OnlyContains( { SCH_PIN_T } ) || m_selection.Empty() )
+                if( !m_selection.OnlyContains( { SCH_PIN_T, SCH_SHEET_PIN_T } )
+                    || m_selection.Empty() )
+                {
                     return 0;
+                }
 
                 // Keep track of new items so we make them the new selection at the end
                 EDA_ITEMS  newItems;
@@ -632,8 +678,7 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
                 {
                     for( EDA_ITEM* item : m_selection )
                     {
-                        SCH_PIN*        pin = static_cast<SCH_PIN*>( item );
-                        SCH_NO_CONNECT* nc = new SCH_NO_CONNECT( pin->GetPosition() );
+                        SCH_NO_CONNECT* nc = new SCH_NO_CONNECT( item->GetPosition() );
                         commit.Add( nc, m_frame->GetScreen() );
                         newItems.push_back( nc );
                     }
@@ -647,14 +692,13 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
 
                     for( EDA_ITEM* item : m_selection )
                     {
-                        SCH_PIN*  pin = static_cast<SCH_PIN*>( item );
-                        SCH_LINE* wire = new SCH_LINE( pin->GetPosition(), LAYER_WIRE );
+                        SCH_LINE* wire = new SCH_LINE( item->GetPosition(), LAYER_WIRE );
 
                         // Add some length to the wire as nothing in our code base handles
                         // 0 length wires very well, least of all the ortho drag algorithm
                         VECTOR2I stub;
 
-                        switch( pin->GetOrientation() )
+                        switch( pinOrientation( item ) )
                         {
                         case PIN_ORIENTATION::PIN_LEFT:
                             stub = VECTOR2I( 1 * wireGrid.x, 0 );
@@ -670,7 +714,7 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
                             break;
                         }
 
-                        wire->SetEndPoint( pin->GetPosition() + stub );
+                        wire->SetEndPoint( item->GetPosition() + stub );
 
                         m_frame->AddToScreen( wire, m_frame->GetScreen() );
                         commit.Added( wire, m_frame->GetScreen() );
@@ -702,24 +746,33 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
                     // selected by the user
                     for( EDA_ITEM* item : m_selection )
                     {
-                        SCH_PIN*        pin = static_cast<SCH_PIN*>( item );
+                        SCH_PIN*        pin = dynamic_cast<SCH_PIN*>( item );
+                        SCH_SHEET_PIN*  sheetPin = dynamic_cast<SCH_SHEET_PIN*>( item );
+                        SCH_EDIT_FRAME* sf = dynamic_cast<SCH_EDIT_FRAME*>( m_frame );
                         SCH_LABEL_BASE* label = nullptr;
 
+                        wxString labelText;
+
+                        if( pin )
+                            labelText = pin->GetShownName();
+                        else if( sheetPin && sf )
+                            labelText = sheetPin->GetShownText( &sf->GetCurrentSheet(), false );
+
                         switch( *evt->GetCommandId() )
                         {
                         case ID_POPUP_SCH_PIN_TRICKS_NET_LABEL:
-                            label = new SCH_LABEL( pin->GetPosition(), pin->GetShownName() );
+                            label = new SCH_LABEL( item->GetPosition(), labelText );
                             break;
                         case ID_POPUP_SCH_PIN_TRICKS_HIER_LABEL:
-                            label = new SCH_HIERLABEL( pin->GetPosition(), pin->GetShownName() );
+                            label = new SCH_HIERLABEL( item->GetPosition(), labelText );
                             break;
                         case ID_POPUP_SCH_PIN_TRICKS_GLOBAL_LABEL:
-                            label = new SCH_GLOBALLABEL( pin->GetPosition(), pin->GetShownName() );
+                            label = new SCH_GLOBALLABEL( item->GetPosition(), labelText );
                             break;
                         default: continue;
                         }
 
-                        switch( pin->GetOrientation() )
+                        switch( pinOrientation( item ) )
                         {
                         case PIN_ORIENTATION::PIN_LEFT:
                             label->SetSpinStyle( SPIN_STYLE::SPIN::RIGHT );
@@ -735,7 +788,25 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
                             break;
                         }
 
-                        switch( pin->GetType() )
+                        ELECTRICAL_PINTYPE pinType = ELECTRICAL_PINTYPE::PT_UNSPECIFIED;
+
+                        if( pin )
+                        {
+                            pinType = pin->GetType();
+                        }
+                        else if( sheetPin )
+                        {
+                            switch( sheetPin->GetLabelShape() )
+                            {
+                            case LABEL_INPUT:    pinType = ELECTRICAL_PINTYPE::PT_INPUT;    break;
+                            case LABEL_OUTPUT:   pinType = ELECTRICAL_PINTYPE::PT_OUTPUT;   break;
+                            case LABEL_BIDI:     pinType = ELECTRICAL_PINTYPE::PT_BIDI;     break;
+                            case LABEL_TRISTATE: pinType = ELECTRICAL_PINTYPE::PT_TRISTATE; break;
+                            case LABEL_PASSIVE:  pinType = ELECTRICAL_PINTYPE::PT_PASSIVE;  break;
+                            }
+                        }
+
+                        switch( pinType )
                         {
                         case ELECTRICAL_PINTYPE::PT_BIDI:
                             label->SetShape( LABEL_FLAG_SHAPE::L_BIDI );
@@ -953,6 +1024,22 @@ OPT_TOOL_EVENT EE_SELECTION_TOOL::autostartEvent( TOOL_EVENT* aEvent, EE_GRID_HE
             if( possibleConnection.IsBus() )
                 newEvt = EE_ACTIONS::drawBus.MakeEvent();
         }
+        else if( aItem->Type() == SCH_SYMBOL_T )
+        {
+            const SCH_SYMBOL* symbol = static_cast<const SCH_SYMBOL*>( aItem );
+
+            wxCHECK( symbol, OPT_TOOL_EVENT() );
+
+            const SCH_PIN* pin = symbol->GetPin( pos );
+
+            wxCHECK( pin, OPT_TOOL_EVENT() );
+
+            if( !pin->IsVisible()
+                && !( m_frame->eeconfig()->m_Appearance.show_hidden_pins ) )
+            {
+                return OPT_TOOL_EVENT();
+            }
+        }
 
         newEvt->SetMousePosition( pos );
         newEvt->SetHasPosition( true );
@@ -1354,8 +1441,14 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
         }
         else
         {
+
+            if( m_frame->GetRenderSettings()->m_ShowPinsElectricalType )
+                item->SetFlags( SHOW_ELEC_TYPE );
+
             if( item->HitTest( aPos, 0 ) )
                 exactHits.insert( item );
+
+            item->ClearFlags( SHOW_ELEC_TYPE );
         }
     }
 
@@ -1382,6 +1475,11 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
         BOX2I bbox = item->GetBoundingBox();
         int   dist = INT_MAX / 4;
 
+        // A dominating item is one that would unfairly win distance tests
+        // and mask out other items. For example, a filled rectangle "wins"
+        // with a zero distance over anything inside it.
+        bool dominating = false;
+
         if( exactHits.count( item ) )
         {
             if( item->Type() == SCH_PIN_T || item->Type() == SCH_JUNCTION_T )
@@ -1438,6 +1536,9 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
 
                     delete s;
                 }
+
+                // Filled shapes win hit tests anywhere inside them
+                dominating = shape->IsFilled();
             }
             else if( symbol )
             {
@@ -1461,15 +1562,21 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
             rect.Collide( poss, collector.m_Threshold, &dist );
         }
 
-        if( dist == closestDist )
+        // Don't promote dominating items to be the closest item
+        // (they'll always win) - they'll still be available for selection, but they
+        // won't boot out worthy competitors.
+        if ( !dominating )
         {
-            if( item->GetParent() == closest )
+            if( dist == closestDist )
+            {
+                if( item->GetParent() == closest )
+                    closest = item;
+            }
+            else if( dist < closestDist )
+            {
+                closestDist = dist;
                 closest = item;
-        }
-        else if( dist < closestDist )
-        {
-            closestDist = dist;
-            closest = item;
+            }
         }
     }
 
