@@ -78,6 +78,8 @@
 #include "project_tree_pane.h"
 #include <widgets/kistatusbar.h>
 
+#include <kiplatform/io.h>
+
 
 /* Note about the project tree build process:
  * Building the project tree can be *very* long if there are a lot of subdirectories in the
@@ -208,6 +210,10 @@ PROJECT_TREE_PANE::PROJECT_TREE_PANE( KICAD_MANAGER_FRAME* parent ) :
 
 PROJECT_TREE_PANE::~PROJECT_TREE_PANE()
 {
+    Disconnect( wxEVT_FSWATCHER,
+             wxFileSystemWatcherEventHandler( PROJECT_TREE_PANE::onFileSystemEvent ) );
+    Unbind( wxEVT_SYS_COLOUR_CHANGED,
+          wxSysColourChangedEventHandler( PROJECT_TREE_PANE::onThemeChanged ), this );
     shutdownFileWatcher();
 }
 
@@ -392,12 +398,8 @@ wxTreeItemId PROJECT_TREE_PANE::addItemToProjectTree( const wxString& aName,
     TREE_FILE_TYPE type = TREE_FILE_TYPE::UNKNOWN;
     wxFileName     fn( aName );
 
-#ifndef __WXMSW__
-    // Files/dirs names starting by "." are not visible files under unices (including MacOS),
-    // but are under MSW.
-    if( fn.GetName().StartsWith( wxT( "." ) ) )
+    if( KIPLATFORM::IO::IsFileHidden( aName ) )
         return wxTreeItemId();
-#endif
 
     if( wxDirExists( aName ) )
     {
@@ -2238,7 +2240,14 @@ void PROJECT_TREE_PANE::onGitCommit( wxCommandEvent& aEvent )
         }
 
         git_oid           oid;
+        // Check if the libgit2 library version is 1.8.0 or higher
+#if( LIBGIT2_VER_MAJOR > 1 ) || ( LIBGIT2_VER_MAJOR == 1 && LIBGIT2_VER_MINOR >= 8 )
+        // For libgit2 version 1.8.0 and above
+        git_commit* const parents[1] = { parent };
+#else
+        // For libgit2 versions older than 1.8.0
         const git_commit* parents[1] = { parent };
+#endif
 
         if( git_commit_create( &oid, repo, "HEAD", author, author, nullptr, commit_msg.mb_str(), tree,
                            1, parents ) != 0 )
