@@ -237,13 +237,19 @@ std::vector<VECTOR2I> PCB_TEXTBOX::GetAnchorAndOppositeCorner() const
 
 
 VECTOR2I PCB_TEXTBOX::GetDrawPos() const
+{
+    return GetDrawPos( false );
+}
+
+
+VECTOR2I PCB_TEXTBOX::GetDrawPos( bool aIsFlipped ) const
 {
     std::vector<VECTOR2I> corners = GetAnchorAndOppositeCorner();
     GR_TEXT_H_ALIGN_T     effectiveAlignment = GetHorizJustify();
     VECTOR2I              textAnchor;
     VECTOR2I              offset;
 
-    if( IsMirrored() )
+    if( IsMirrored() != aIsFlipped )
     {
         switch( GetHorizJustify() )
         {
@@ -311,29 +317,33 @@ void PCB_TEXTBOX::ViewGetLayers( int aLayers[], int& aCount ) const
 
 wxString PCB_TEXTBOX::GetShownText( bool aAllowExtraText, int aDepth ) const
 {
-    BOARD* board = dynamic_cast<BOARD*>( GetParent() );
+    const FOOTPRINT* parentFootprint = GetParentFootprint();
+    const BOARD*     board = GetBoard();
 
-    std::function<bool( wxString* )> pcbTextResolver =
-            [&]( wxString* token ) -> bool
-            {
-                if( token->IsSameAs( wxT( "LAYER" ) ) )
-                {
-                    *token = GetLayerName();
-                    return true;
-                }
+    std::function<bool( wxString* )> resolver = [&]( wxString* token ) -> bool
+    {
+        if( parentFootprint && parentFootprint->ResolveTextVar( token, aDepth + 1 ) )
+            return true;
 
-                if( board->ResolveTextVar( token, aDepth + 1 ) )
-                {
-                    return true;
-                }
+        if( token->IsSameAs( wxT( "LAYER" ) ) )
+        {
+            *token = GetLayerName();
+            return true;
+        }
 
-                return false;
-            };
+        if( board->ResolveTextVar( token, aDepth + 1 ) )
+            return true;
+
+        return false;
+    };
 
     wxString text = EDA_TEXT::GetShownText( aAllowExtraText, aDepth );
 
-    if( board && HasTextVars() && aDepth < 10 )
-        text = ExpandTextVars( text, &pcbTextResolver );
+    if( HasTextVars() )
+    {
+        if( aDepth < 10 )
+            text = ExpandTextVars( text, &resolver );
+    }
 
     KIFONT::FONT*         font = getDrawFont();
     std::vector<VECTOR2I> corners = GetAnchorAndOppositeCorner();
